List of highest mountains

# List of highest mountains on Earth

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search
Wikimedia list article

| This article possibly contains original research. Please improve it by verifying the claims made and adding inline citations. Statements consisting only of original research should be removed. (September 2021) (Learn how and when to remove this template message)

Aerial view of Mount Everest from the south. The peak rises over Lhotse, while Nuptse is the ridge on the left.

There are at least 108 mountains on Earth with elevations of 7,200 metres (23,622 ft) or greater above sea level. The vast majority of these mountains are located on the edge of the Indian and Eurasian plates in China, India, Nepal and Pakistan.

The highest mountains above sea level are also not those with peaks farthest from the centre of the Earth, because the figure of the Earth is not spherical. Sea level closer to the equator is several kilometres farther from the centre of the Earth. The summit of Chimborazo, Ecuador's tallest mountain, is usually considered to be the farthest point from the Earth's centre, although the southern summit of Peru's tallest mountain, Huascarán, is another contender.[3] Both have elevations above sea level more than 2 km less than that of Everest.

## Geographical distribution[edit]

Map all coordinates using: OpenStreetMap
Download coordinates as: KML

Almost all mountains in the list are located in the Himalaya and Karakoram ranges to the south and west of the Tibetan plateau. All peaks 7,000 m (23,000 ft) or higher are located in East, Central or South Asia in a rectangle edged by Noshaq (7,492 m or 24,580 ft) on the Afghanistan–Pakistan border in the west, Jengish Chokusu (Tuōmù'ěr Fēng, 7,439 m or 24,406 ft) on the Kyrgyzstan–Xinjiang border to the north, Gongga Shan (Minya Konka, 7,556 m or 24,790 ft) in Sichuan to the east, and Kabru (7,412 m or 24,318 ft) on the Sikkim–Nepal border to the south.

As of December 2018[update], the highest peaks on four of the mountains — Gangkhar Puensum, Labuche Kang III, Karjiang, and Tongshanjiabu, all located in Bhutan or China — have not been ascended. The most recent peak to have its first ever ascent is Saser Kangri II East, in India, on 24 August 2011.

The highest mountain outside of Asia is Aconcagua (6,961 m or 22,838 ft), the 189th highest in the world.[4]

## List of world's highest peaks[edit]

Rank [dp 1] | Mountain name(s) | Height (rounded) [dp 2] | Prominence (rounded) [dp 3] | Range | Coordinates [dp 4] | Parent mountain [dp 5] | Ascents before 2004[dp 6] | Country
--- | --- | --- | --- | --- | --- | --- | --- | ---
1st | successful
m | ft | m | ft | y | n
1 | Mount Everest Sagarmatha Chomolungma | 8,848 | 29,029 [dp 7] | 8,848 | 29,029 | Mahalangur Himalaya | 27°59′17″N 86°55′31″E﻿ / ﻿27.9881°N 86.9253°E﻿ / 27.9881; 86.9253﻿ (1. Mount Everest / Sagarmatha / Chomolungma / Zhumulangma (8848 m)) | — | 1953 | 145 | 121 | Nepal China
2 | K2 | 8,611 | 28,251 | 4,020 | 13,190 | Baltoro Karakoram | 35°52′53″N 76°30′48″E﻿ / ﻿35.88139°N 76.51333°E﻿ / 35.88139; 76.51333﻿ (2. K2 / Qogir / Godwin Austen (8611 m)) | Mount Everest | 1954 | 45 | 44 | Pakistan[dp 8] China[12]
3 | Kangchenjunga | 8,586 | 28,169 | 3,922 | 12,867 | Kangchenjunga Himalaya | 27°42′12″N 88°08′51″E﻿ / ﻿27.70333°N 88.14750°E﻿ / 27.70333; 88.14750﻿ (3. Kangchenjunga (8586 m)) * | Mount Everest | 1955 | 38 | 24 | Nepal India